SLiCAPkicad.py — SLiCAP 4.0.7 documentation

# SLiCAPkicad.py

SLiCAP module for interfacing with KiCAD

KiCADsch2svg(fileName)

  Creates drawing-size images in .SVG and .PDF format from KiCad schematics. The image files will be placed in the img subdirectory in the project fodler. The names of the image files equal that of the schematic file, but the file extensions differ (.svg and .pdf).

  Parameters:

    fileName (str) – Name of the KiCad schematic file, relative to project folder or absolute

backAnnotateSchematic(sch, opinfo)

  1. Replaces text labels <label> on a KiCAD schematic with <label>:<opinfo[label]>

  2. Creates drawing-size `svg` and `pdf` images of the annotated schematic

  3. Saves the annotated schematic

  Parameters:

    - sch (str) – File of the KiCAD schematic with annotation text labels; location relative to project directory

    - opinfo –

      Dictionary with key-value pairs:

      - key: label text

      - value: text to be appended to the label

  Returns:

    None

  Return type:

    NoneType